### Name: RiboSort
### Title: Preparation of Microbial Community Profiles for Statistical
###   Analyses
### Aliases: RiboSort
### Keywords: manip multivariate

### ** Examples

#Note: The four examples below make use of several demonstration datafiles provided with the RiboSort package. The line beginning file.copy(...) in each example, simply copies the neccessary demonstration datafiles from the RiboSort package into your current working directory. 

#Example 1: Data in standard profile format. 6 profiles, 2 repeats per sample.
#We specify that the RiboSort object x is to contain proportions, and the 
#present-in-one method is used to merge repeats.

data(demo.standard)
demo.standard
file.copy(system.file(demo.standard, package = "RiboSort"), ".")
x=RiboSort(data=demo.standard, dataformat="standard", output="proportions", 
             zerorows=FALSE, repeats=2, mergerepeats="presentinone")
x[1:10,]                #prints the first 10 rows of the matrix x. 
samplesMDS(x)           #produces an MDS plot of the three samples.

#----------------------------------------------------------------------------------
#Example 2: Data in Beckman Sequencer format. 4 profiles, 1 repeat per sample.
#We specify that the RiboSort object y is to contain abundances.

data(demo.beckman)
demo.beckman
file.copy(system.file(demo.beckman, package = "RiboSort"), ".")
y=RiboSort(data=demo.beckman, dataformat="beckman", dye="D4", output="abundances",
           zerorows=FALSE, repeats=1, mergerepeats="none")
y[1:10,]                #prints the first 10 rows of the matrix y. 
samplesMDS(y)           #produces an MDS plot of the four samples.

#----------------------------------------------------------------------------------
#Example 3 : Data from ABI Sequencer files, each containing a single profile. 
#5 profiles, 1 repeat per sample.
#We specify that the RiboSort object z will contain abundances.

data(demo.abi.single)
demo.abi.single
file.copy(system.file(demo.abi.single, package = "RiboSort"), ".")
z=RiboSort(data=demo.abi.single, dataformat="abisingle", dye="B", output="abundances",
           zerorows=FALSE, repeats=1, mergerepeats="none")
z[1:10,]                #prints the first 10 rows of the matrix z. 
samplesMDS(z)           #produces an MDS plot of the five samples.


#----------------------------------------------------------------------------------
#Example 4: Data from an ABI Sequencer file that contains multiple profiles. 
#8 profiles, 1 repeat per sample.
#We specify that the RiboSort object q will contain abundances.

data(demo.abi.multiple)
demo.abi.multiple
file.copy(system.file(demo.abi.multiple, package = "RiboSort"), ".")
q=RiboSort(data=demo.abi.multiple, dataformat="abimultiple", output="abundances",
           zerorows=FALSE, repeats=1, mergerepeats="none")
q[1:10,]                #prints the first 10 rows of the matrix q. 
samplesMDS(q)           #produces an MDS plot of the eight samples.




